==> laminci-0.13.1.tar.gz: laminci-0.13.1/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
✨ Add run function to nox | [36](https://github.com/laminlabs/laminci/pull/36) | [falexwolf](https://github.com/falexwolf) | 2024-04-25 | 0.13.1
♻️ Make compat with 3.8 | [35](https://github.com/laminlabs/laminci/pull/35) | [falexwolf](https://github.com/falexwolf) | 2024-04-05 | 0.12.1
♻️ UV for docs building | [34](https://github.com/laminlabs/laminci/pull/34) | [Zethson](https://github.com/Zethson) | 2024-03-25 | 0.12.0
🔇 Silence more loggers | [33](https://github.com/laminlabs/laminci/pull/33) | [falexwolf](https://github.com/falexwolf) | 2024-02-29 | 0.11.3
🎨 Pull testuser API keys from AWS secrets | [32](https://github.com/laminlabs/laminci/pull/32) | [falexwolf](https://github.com/falexwolf) | 2024-01-06 | 0.11.0
🎨 Remove duplication of public private nox module | [31](https://github.com/laminlabs/laminci/pull/31) | [falexwolf](https://github.com/falexwolf) | 2024-01-06 | 0.10.0
🚸 Silence httpx logger | [30](https://github.com/laminlabs/laminci/pull/30) | [falexwolf](https://github.com/falexwolf) | 2024-01-06 |
Automatically make Github releases | [28](https://github.com/laminlabs/laminci/pull/28) | [Zethson](https://github.com/Zethson) | 2023-11-23 |
♻️ Replace CLI with lamindb-setup API calls | [26](https://github.com/laminlabs/laminci/pull/26) | [falexwolf](https://github.com/falexwolf) | 2023-10-30 | 0.9.0
🚸 Return `get_package_name` returns `None` if there is no Python package | [25](https://github.com/laminlabs/laminci/pull/25) | [falexwolf](https://github.com/falexwolf) | 2023-08-18 | 0.8.0
📝 Account for blog | [24](https://github.com/laminlabs/laminci/pull/24) | [falexwolf](https://github.com/falexwolf) | 2023-08-04 | 0.7.7
🚸 Add light-weight release management | [23](https://github.com/laminlabs/laminci/pull/23) | [falexwolf](https://github.com/falexwolf) | 2023-06-14 | 0.7.4
✨ Add `repository_dispatch` for docs upload | [22](https://github.com/laminlabs/laminci/pull/22) | [falexwolf](https://github.com/falexwolf) | 2023-06-14 | 0.6.8
🚸 Add fallback for `get_package_name` | [21](https://github.com/laminlabs/laminci/pull/21) | [falexwolf](https://github.com/falexwolf) | 2023-06-14 | 0.6.7
✨ Add aws cli based way of pushing a docs artifact | [20](https://github.com/laminlabs/laminci/pull/20) | [falexwolf](https://github.com/falexwolf) | 2023-05-26 | 0.6.4
🚸 Allow passing version to `setup_local_test_postgres` | [19](https://github.com/laminlabs/laminci/pull/19) | [falexwolf](https://github.com/falexwolf) | 2023-04-20 |
🚸 Close current instance before uploading docs artifacts | [17](https://github.com/laminlabs/laminci/pull/17) | [falexwolf](https://github.com/falexwolf) | 2023-04-10 | 0.5.3
🚸 Add support for environments | [16](https://github.com/laminlabs/laminci/pull/16) | [falexwolf](https://github.com/falexwolf) | 2023-04-10 | 0.5.1
⬆️ Upgrade to new replace API | [15](https://github.com/laminlabs/laminci/pull/15) | [falexwolf](https://github.com/falexwolf) | 2023-04-10 | 0.5.0
♻️ Replace `lndb` with `lamin` | [14](https://github.com/laminlabs/laminci/pull/14) | [falexwolf](https://github.com/falexwolf) | 2023-03-29 | 0.4.2
🚸 Replace git checkout with git switch | [13](https://github.com/laminlabs/laminci/pull/13) | [falexwolf](https://github.com/falexwolf) | 2023-03-27 | 0.4.1
⬆️ Upgrade to LaminDB v0.35 | [12](https://github.com/laminlabs/laminci/pull/12) | [falexwolf](https://github.com/falexwolf) | 2023-03-26 | 0.4.0
🚚 Rename `upload_docs_dir` to `upload_docs_artifact` |  | 2023-03-21 | 0.3.4
🍱 Track images in docs | [11](https://github.com/laminlabs/laminci/pull/11) | [falexwolf](https://github.com/falexwolf) | 2023-03-12 | 0.3.2
➖ Remove dependency on lamindb in laminci | [10](https://github.com/laminlabs/laminci/pull/10) | [falexwolf](https://github.com/falexwolf) | 2023-03-09 | 0.3.0 / 0.3.1
🍱 Track readme in docs upload | [9](https://github.com/laminlabs/laminci/pull/9) | [falexwolf](https://github.com/falexwolf) | 2023-03-06 | 0.2.5
🐛 Implement overwrite | [8](https://github.com/laminlabs/laminci/pull/8) | [falexwolf](https://github.com/falexwolf) | 2023-02-28 | 0.2.4
:zap: Only include docs files | [7](https://github.com/laminlabs/laminci/pull/7) | [falexwolf](https://github.com/falexwolf) | 2023-02-27 | 0.2.3
🐛 Fix coverage call | [6](https://github.com/laminlabs/laminci/pull/6) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 | 0.2.2
🚸 Make coverage calculation optional | [5](https://github.com/laminlabs/laminci/pull/5) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 | 0.2.1
✨ Move docs | [4](https://github.com/laminlabs/laminci/pull/4) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.2.0
🐛 Fix | [3](https://github.com/laminlabs/laminci/pull/3) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.1
🚚 Move code from lndb | [2](https://github.com/laminlabs/laminci/pull/2) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.0
🔥 Remove unnecessary files | [1](https://github.com/laminlabs/laminci/pull/1) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 |

==> laminci-0.14.0.tar.gz: laminci-0.14.0/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
✨ Add install_lamindb to install lamindb from github | [40](https://github.com/laminlabs/laminci/pull/40) | [Koncopd](https://github.com/Koncopd) | 2024-07-26 |
🚸 Publish to laminhub-public | [41](https://github.com/laminlabs/laminci/pull/41) | [falexwolf](https://github.com/falexwolf) | 2024-07-22 |
✨ Manage UI releases | [39](https://github.com/laminlabs/laminci/pull/39) | [falexwolf](https://github.com/falexwolf) | 2024-07-06 |
♻️ Add a variable for the --system flag | [38](https://github.com/laminlabs/laminci/pull/38) | [falexwolf](https://github.com/falexwolf) | 2024-06-26 |
✨ Add run function to nox | [36](https://github.com/laminlabs/laminci/pull/36) | [falexwolf](https://github.com/falexwolf) | 2024-04-25 | 0.13.1
♻️ Make compat with 3.8 | [35](https://github.com/laminlabs/laminci/pull/35) | [falexwolf](https://github.com/falexwolf) | 2024-04-05 | 0.12.1
♻️ UV for docs building | [34](https://github.com/laminlabs/laminci/pull/34) | [Zethson](https://github.com/Zethson) | 2024-03-25 | 0.12.0
🔇 Silence more loggers | [33](https://github.com/laminlabs/laminci/pull/33) | [falexwolf](https://github.com/falexwolf) | 2024-02-29 | 0.11.3
🎨 Pull testuser API keys from AWS secrets | [32](https://github.com/laminlabs/laminci/pull/32) | [falexwolf](https://github.com/falexwolf) | 2024-01-06 | 0.11.0
🎨 Remove duplication of public private nox module | [31](https://github.com/laminlabs/laminci/pull/31) | [falexwolf](https://github.com/falexwolf) | 2024-01-06 | 0.10.0
🚸 Silence httpx logger | [30](https://github.com/laminlabs/laminci/pull/30) | [falexwolf](https://github.com/falexwolf) | 2024-01-06 |
Automatically make Github releases | [28](https://github.com/laminlabs/laminci/pull/28) | [Zethson](https://github.com/Zethson) | 2023-11-23 |
♻️ Replace CLI with lamindb-setup API calls | [26](https://github.com/laminlabs/laminci/pull/26) | [falexwolf](https://github.com/falexwolf) | 2023-10-30 | 0.9.0
🚸 Return `get_package_name` returns `None` if there is no Python package | [25](https://github.com/laminlabs/laminci/pull/25) | [falexwolf](https://github.com/falexwolf) | 2023-08-18 | 0.8.0
📝 Account for blog | [24](https://github.com/laminlabs/laminci/pull/24) | [falexwolf](https://github.com/falexwolf) | 2023-08-04 | 0.7.7
🚸 Add light-weight release management | [23](https://github.com/laminlabs/laminci/pull/23) | [falexwolf](https://github.com/falexwolf) | 2023-06-14 | 0.7.4
✨ Add `repository_dispatch` for docs upload | [22](https://github.com/laminlabs/laminci/pull/22) | [falexwolf](https://github.com/falexwolf) | 2023-06-14 | 0.6.8
🚸 Add fallback for `get_package_name` | [21](https://github.com/laminlabs/laminci/pull/21) | [falexwolf](https://github.com/falexwolf) | 2023-06-14 | 0.6.7
✨ Add aws cli based way of pushing a docs artifact | [20](https://github.com/laminlabs/laminci/pull/20) | [falexwolf](https://github.com/falexwolf) | 2023-05-26 | 0.6.4
🚸 Allow passing version to `setup_local_test_postgres` | [19](https://github.com/laminlabs/laminci/pull/19) | [falexwolf](https://github.com/falexwolf) | 2023-04-20 |
🚸 Close current instance before uploading docs artifacts | [17](https://github.com/laminlabs/laminci/pull/17) | [falexwolf](https://github.com/falexwolf) | 2023-04-10 | 0.5.3
🚸 Add support for environments | [16](https://github.com/laminlabs/laminci/pull/16) | [falexwolf](https://github.com/falexwolf) | 2023-04-10 | 0.5.1
⬆️ Upgrade to new replace API | [15](https://github.com/laminlabs/laminci/pull/15) | [falexwolf](https://github.com/falexwolf) | 2023-04-10 | 0.5.0
♻️ Replace `lndb` with `lamin` | [14](https://github.com/laminlabs/laminci/pull/14) | [falexwolf](https://github.com/falexwolf) | 2023-03-29 | 0.4.2
🚸 Replace git checkout with git switch | [13](https://github.com/laminlabs/laminci/pull/13) | [falexwolf](https://github.com/falexwolf) | 2023-03-27 | 0.4.1
⬆️ Upgrade to LaminDB v0.35 | [12](https://github.com/laminlabs/laminci/pull/12) | [falexwolf](https://github.com/falexwolf) | 2023-03-26 | 0.4.0
🚚 Rename `upload_docs_dir` to `upload_docs_artifact` |  | 2023-03-21 | 0.3.4
🍱 Track images in docs | [11](https://github.com/laminlabs/laminci/pull/11) | [falexwolf](https://github.com/falexwolf) | 2023-03-12 | 0.3.2
➖ Remove dependency on lamindb in laminci | [10](https://github.com/laminlabs/laminci/pull/10) | [falexwolf](https://github.com/falexwolf) | 2023-03-09 | 0.3.0 / 0.3.1
🍱 Track readme in docs upload | [9](https://github.com/laminlabs/laminci/pull/9) | [falexwolf](https://github.com/falexwolf) | 2023-03-06 | 0.2.5
🐛 Implement overwrite | [8](https://github.com/laminlabs/laminci/pull/8) | [falexwolf](https://github.com/falexwolf) | 2023-02-28 | 0.2.4
:zap: Only include docs files | [7](https://github.com/laminlabs/laminci/pull/7) | [falexwolf](https://github.com/falexwolf) | 2023-02-27 | 0.2.3
🐛 Fix coverage call | [6](https://github.com/laminlabs/laminci/pull/6) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 | 0.2.2
🚸 Make coverage calculation optional | [5](https://github.com/laminlabs/laminci/pull/5) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 | 0.2.1
✨ Move docs | [4](https://github.com/laminlabs/laminci/pull/4) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.2.0
🐛 Fix | [3](https://github.com/laminlabs/laminci/pull/3) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.1
🚚 Move code from lndb | [2](https://github.com/laminlabs/laminci/pull/2) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.0
🔥 Remove unnecessary files | [1](https://github.com/laminlabs/laminci/pull/1) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 |
